@@ -12,8 +12,7 @@ def __start() -> None:
     from sys import version_info as info
     from colorama import Fore, Style
     from .version import ver
-    color = '' if rint(0, 1) else Fore.GREEN if not rint(
-        0, 4) else Fore.YELLOW if rint(0, 1) else Fore.BLUE
+    color = '' if rint(0, 1) else Fore.GREEN if not rint(0, 4) else Fore.YELLOW if rint(0, 1) else Fore.BLUE
     print(f"{color}fxxkpy {ver} (Python {'.'.join(map(str, info[0:3]))})")
     print(FxxkPy, end='')
     print(Style.RESET_ALL)
